@@ -184,8 +184,8 @@ def update_requirements_version(uo_folder, lbt_version):
             requirements.txt file.
     """
     req_file = os.path.join(uo_folder, 'requirements.txt')
+    all_rows = []
     if os.path.isfile(req_file):
-        all_rows = []
         with open(req_file) as rf:
             for row in rf:
                 if row.startswith('lbt-grasshopper=='):
@@ -306,6 +306,15 @@ def change_installed_version(version_to_install=None):
         print(stderr)
     set_config_dict(config_dict)  # restore the previous configurations
 
+    # install the lbt_recipes package
+    print('Installing Ladybug Tools Recipes.')
+    rec_ver = ver_dict['lbt-recipes']
+    stderr = update_libraries_pip(py_exe, 'lbt-recipes', rec_ver)
+    if os.path.isdir(os.path.join(py_lib, 'lbt_recipes-{}.dist-info'.format(rec_ver))):
+        print('Ladybug Tools Recipes successfully installed!\n ')
+    else:
+        print(stderr)
+
     # install the library needed for interaction with Rhino
     print('Installing ladybug-rhino Python library.')
     rh_ver = ver_dict['ladybug-rhino']
@@ -314,7 +323,9 @@ def change_installed_version(version_to_install=None):
         print('Ladybug-rhino Python library successfully installed!\n ')
     else:
         print(stderr)
-    if os.name != 'nt':  # make sure libraries are copied to the rhino scripts folder
+
+    # make sure libraries are copied to the rhino scripts folder on Mac
+    if os.name != 'nt':
         iron_python_search_path(create_python_package_dir())
 
     # install the grasshopper components
@@ -354,15 +365,6 @@ def change_installed_version(version_to_install=None):
         else:
             print(stderr)
 
-    # install the lbt_recipes package
-    print('Installing Ladybug Tools Recipes.')
-    rec_ver = ver_dict['lbt-recipes']
-    stderr = update_libraries_pip(py_exe, 'lbt-recipes', rec_ver)
-    if os.path.isdir(os.path.join(py_lib, 'lbt_recipes-{}.dist-info'.format(rec_ver))):
-        print('Ladybug Tools Recipes successfully installed!\n ')
-    else:
-        print(stderr)
-
     # install the honeybee-openstudio ruby gem
     gem_ver = ver_dict['honeybee-openstudio-gem']
     print('Installing Honeybee-OpenStudio gem version {}.'.format(gem_ver))
